.. _samlp:

***************************************************
Base classes representing Saml2.0 protocol elements
***************************************************

:Author: Roland Hedberg
:Version: |version|

.. module:: SAMLP
   :synopsis: Base classes representing Saml2.0 protocol elements.
   
Module
==========

.. automodule:: saml2.samlp
   :members: 

